==> wammu_0.42.orig.tar.xz: wammu-0.42/README.cs <==
Wammu
=====

GUI pro Gammu.

.. image:: https://hosted.weblate.org/widgets/gammu/-/svg-badge.svg
    :alt: Stav překladu :target:
    https://hosted.weblate.org/engage/gammu/?utm_source=widget

.. image:: https://landscape.io/github/gammu/wammu/master/landscape.svg?style=flat
    :target: https://landscape.io/github/gammu/wammu/master :alt: Zdraví kódu

.. image:: https://img.shields.io/gratipay/Gammu.svg
    :alt: Gratipay :target: https://gratipay.com/Gammu/

.. image:: https://www.bountysource.com/badge/team?team_id=23177&style=bounties_received
    :alt: Bountysource :target:
    https://www.bountysource.com/teams/gammu/issues?utm_source=Gammu&utm_medium=shield&utm_campaign=bounties_received

.. image:: https://todofy.org/b/gammu/wammu
    :target: https://todofy.org/r/gammu/wammu

Domovská stránka
================

<http://cs.wammu.eu/>

Licence
=======

GNU GPL verze 2.

První spuštění
==============

Při prvním startu budete požádáni o nastavení připojení k telefonu. Pokud
jste ještě nepoužili Gammu/Wammu, bude vám navrhnuto vyhledání telefonu,
které by mělo ve většině případů nalézt správnou konfiguraci.

Použití
=======

Nejdříve se musíte připojit k telefonu, pak s ním můžete provádět nějaké
operace. Pro vytváření záznamů a pro import nepotřebujete načíst data z
telefonu, pro ostatní musíte (překvapivě? :-)).

Všechny akce s aktuálními daty jsou dostupné také z kontextového menu na
každé položky. Můžete také použít klávesu Enter pro upravení položky a
Delete pro vymazání.

Zálohování uloží všechny položky, který jste již načetli z telefonu.

Hlášení chyb
============

Nalezené chyby prosím nahlašte na <http://bugs.wammu.eu>.

Překládání
==========

Můžete pomoci přeložit Wammu do jazyka, který umíte -
<https://hosted.weblate.org/projects/wammu/>.

Správa revizí
=============

Vývoj probíhá v Gitu, hlavní vývojovou větev naleznete na
<git://github.com/gammu/wammu.git> a prohlížet si jí můžete na stránkách
<https://github.com/gammu/wammu>.

==> wammu_0.44.orig.tar.xz: wammu-0.44/README.cs <==
Wammu
=====

Grafické rozhraní pro `knihovnu Gammu <https://cs.wammu.eu/gammu/>`_.

.. image:: https://hosted.weblate.org/widgets/gammu/-/svg-badge.svg
    :alt: Překlady status :target:
    https://hosted.weblate.org/engage/gammu/?utm_source=widget

.. image:: https://landscape.io/github/gammu/wammu/master/landscape.svg?style=flat
    :target: https://landscape.io/github/gammu/wammu/master :alt: Zdraví kódu

.. image:: https://img.shields.io/gratipay/Gammu.svg
    :alt: Gratipay :target: https://gratipay.com/Gammu/

.. image:: https://www.bountysource.com/badge/team?team_id=23177&style=bounties_received
    :alt: Bountysource :target:
    https://www.bountysource.com/teams/gammu/issues?utm_source=Gammu&utm_medium=shield&utm_campaign=bounties_received

.. image:: https://travis-ci.org/gammu/wammu.svg?branch=master
    :target: https://travis-ci.org/gammu/wammu

Domovská stránka
================

<https://cs.wammu.eu/>

Licence
=======

GNU GPL verze 3 nebo novější.

První spuštění
==============

Při prvním startu budete požádáni o nastavení připojení k telefonu. Pokud
jste ještě nepoužili Gammu/Wammu, bude vám navrhnuto vyhledání telefonu,
které by mělo ve většině případů nalézt správnou konfiguraci.

Použití
=======

Nejdříve se musíte připojit k telefonu, pak s ním můžete provádět nějaké
operace. Pro vytváření záznamů a pro import nepotřebujete načíst data z
telefonu, pro ostatní musíte (překvapivě? :-)).

Všechny akce s aktuálními daty jsou dostupné také z kontextového menu na
každé položky. Můžete také použít klávesu Enter pro upravení položky a
Delete pro vymazání.

Zálohování uloží všechny položky, který jste již načetli z telefonu.

Hlášení chyb
============

Nalezené chyby prosím nahlaste na <https://github.com/gammu/wammu/issues/>.

Překládání
==========

Můžete pomoci přeložit Wammu do jazyka, který umíte -
<https://hosted.weblate.org/projects/wammu/>.

Správa revizí
=============

Vývoj probíhá v Gitu, hlavní vývojovou větev naleznete na
<git://github.com/gammu/wammu.git> a prohlížet si jí můžete na stránkách
<https://github.com/gammu/wammu>.
